==> nhl_api_client-1.0.0.tar.gz: nhl_api_client-1.0.0/nhl_api_client/api/default/get_score_details_by_date.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.get_score_details_by_date_response_200 import GetScoreDetailsByDateResponse200
from ...types import Response


def _get_kwargs() -> Dict[str, Any]:
    pass

    return {
        "method": "get",
        "url": "/v1/score/2023-11-08",
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[GetScoreDetailsByDateResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = GetScoreDetailsByDateResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[GetScoreDetailsByDateResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GetScoreDetailsByDateResponse200]:
    """/v1/score/2023-11-08

     **Host**: http://api-web.nhle.com

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetScoreDetailsByDateResponse200]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GetScoreDetailsByDateResponse200]:
    """/v1/score/2023-11-08

     **Host**: http://api-web.nhle.com

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetScoreDetailsByDateResponse200
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[GetScoreDetailsByDateResponse200]:
    """/v1/score/2023-11-08

     **Host**: http://api-web.nhle.com

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetScoreDetailsByDateResponse200]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[GetScoreDetailsByDateResponse200]:
    """/v1/score/2023-11-08

     **Host**: http://api-web.nhle.com

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetScoreDetailsByDateResponse200
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> nhl_api_client-1.0.6.tar.gz: nhl_api_client-1.0.6/nhl_api_client/api/default/get_score_details_by_date.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response
from ... import errors

from typing import Dict
from ...models.score_details import ScoreDetails


def _get_kwargs(
    date: str,
) -> Dict[str, Any]:
    pass

    return {
        "method": "get",
        "url": "/v1/score/{date}".format(
            date=date,
        ),
    }


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[ScoreDetails]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ScoreDetails.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[ScoreDetails]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    date: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[ScoreDetails]:
    """/v1/score/date

     **Host**: http://api-web.nhle.com

    Args:
        date (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ScoreDetails]
    """

    kwargs = _get_kwargs(
        date=date,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    date: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[ScoreDetails]:
    """/v1/score/date

     **Host**: http://api-web.nhle.com

    Args:
        date (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ScoreDetails
    """

    return sync_detailed(
        date=date,
        client=client,
    ).parsed


async def asyncio_detailed(
    date: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[ScoreDetails]:
    """/v1/score/date

     **Host**: http://api-web.nhle.com

    Args:
        date (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[ScoreDetails]
    """

    kwargs = _get_kwargs(
        date=date,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    date: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[ScoreDetails]:
    """/v1/score/date

     **Host**: http://api-web.nhle.com

    Args:
        date (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        ScoreDetails
    """

    return (
        await asyncio_detailed(
            date=date,
            client=client,
        )
    ).parsed
